"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var rubyann_1 = require("../rubyann");
chai.should();
describe('RubyAnn annotates to ruby XML', function () {
    var BirdXml = 'bird=<ruby><rb>鳥</rb><rp>(</rp><rt>とり</rt><rp>)</rp></ruby>';
    var rubyAnn = new rubyann_1.RubyAnn();
    it('can annotate 1 kanji', function () {
        rubyAnn.getXml('bird={鳥,とり}')
            .should.eq(BirdXml);
    });
    it('can annotate multiple kanji - 2 repeated', function () {
        rubyAnn.getXml('bird={鳥,とり}' + 'bird={鳥,とり}')
            .should.eq(BirdXml + BirdXml);
    });
    it('can annotate multiple kanji - 4 different', function () {
        var OneStoneTwoBirdsXml = '<ruby><rb>一</rb><rp>(</rp><rt>one</rt><rp>)</rp></ruby>' +
            '<ruby><rb>石</rb><rp>(</rp><rt>stone</rt><rp>)</rp></ruby>' +
            '<ruby><rb>二</rb><rp>(</rp><rt>two</rt><rp>)</rp></ruby>' +
            '<ruby><rb>鳥</rb><rp>(</rp><rt>birds</rt><rp>)</rp></ruby>';
        var xml = rubyAnn.getXml('{一,one}{石,stone}{二,two}{鳥,birds}');
        xml.should.eq(OneStoneTwoBirdsXml);
    });
    it('can annotate with non-default delimiters', function () {
        var ra = new rubyann_1.RubyAnn({ delimiters: '[]' });
        ra.getXml('bird=[鳥,とり]')
            .should.eq(BirdXml);
    });
    it('can annotate with 2 same delimiters (not open/close type)', function () {
        var ra = new rubyann_1.RubyAnn({ delimiters: '||' });
        ra.getXml('bird=|鳥,とり|')
            .should.eq(BirdXml);
    });
    it('throws if delimiters are invalid - 1 character', function () {
        chai.expect(function () { return new rubyann_1.RubyAnn({ delimiters: '/' }); }).to.throw("invalid delimiters: '/'");
    });
    it('throws if delimiters are invalid - 3 characters', function () {
        chai.expect(function () { return new rubyann_1.RubyAnn({ delimiters: '|||' }); }).to.throw("invalid delimiters: '|||'");
    });
});
